@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mocker" "0.5.0"
+(define-package "mocker" "20260204.1045"
   "Mocking framework for emacs."
   '((emacs "25.1"))
   :url "https://github.com/sigma/mocker.el"
-  :commit "5d739d5170ff42e841cd2755b68151918052da2b"
-  :revdesc "5d739d5170ff"
+  :commit "462e4aa140db1f0589ab71dd07ee509e5425e2ff"
+  :revdesc "462e4aa140db"
   :keywords '("lisp" "testing")
   :authors '(("Yann Hodique" . "yann.hodique@gmail.com"))
   :maintainers '(("Yann Hodique" . "yann.hodique@gmail.com")))
